[**Начало работы**](./getting-started.md) > **Установка** > **Windows EXE** _(текущая)_

---

### Установка PDFMathTranslate через файл .exe

***Шаг 1*** | Загрузите `pdf2zh-<version>-with-assets-win64.zip` со [страницы релизов](https://github.com/PDFMathTranslate/PDFMathTranslate-next/releases).

> [!TIP]
> **В чем разница между `pdf2zh-<version>-with-assets-win64.zip` и `pdf2zh-<version>-win64.zip`?**
>
> - Если вы скачиваете и используете PDFMathTranslate впервые, рекомендуется загрузить `pdf2zh-<version>-with-assets-win64.zip`.
> - В `pdf2zh-<version>-with-assets-win64.zip` включены файлы ресурсов (например, шрифты и модели) по сравнению с `pdf2zh-<version>-win64.zip`.
> - Версия без ресурсов также будет динамически загружать их при запуске, но загрузка может завершиться неудачей из-за проблем с сетью.

***Шаг 2*** | Распакуйте `pdf2zh-<version>-with-assets-win64.zip` и перейдите в папку `pdf2zh`. Распаковка может занять некоторое время, пожалуйста, подождите.

***Шаг 3*** | Перейдите в папку `pdf2zh`, затем дважды щелкните `pdf2zh.exe`.

> [!TIP]
> **Не удается запустить файл .exe**
>
> Если у вас возникли проблемы с запуском pdf2zh.exe, установите `https://aka.ms/vs/17/release/vc_redist.x64.exe` и попробуйте снова.

***Шаг 4*** | После двойного щелчка по файлу exe откроется терминал. Примерно через полминуты или минуту в вашем браузере по умолчанию откроется веб-страница. Если этого не произошло, попробуйте вручную перейти по адресу `http://localhost:7860/`.

> [!NOTE]
>
> Если у вас возникли проблемы при использовании WebUI, обратитесь к [этой веб-странице](./USAGE_webui.md).

***Шаг 5*** | Наслаждайтесь!

> [!TIP]
> **Вы можете использовать файл .exe через командную строку**
>
> Используйте файл .exe через командную строку следующим образом:
>
> - Запустите терминал и перейдите в папку, содержащую файл .exe:
>
> ```bash
> cd /path/pdf2zh_next/build
> ```
>
> - Вызовите файл .exe:
>
> ```bash
> ./pdf2zh_next.exe "document.pdf"
> ```
>
> Вы можете использовать другие параметры командной строки как обычно:
>
> ```bash
> ./pdf2zh_next.exe "document.pdf" --lang-in en --lang-out ja
> ```
>
> Если вам нужна дополнительная информация об использовании командной строки, обратитесь к этой статье.

<div align="right"> 
<h6><small>Часть содержимого этой страницы была переведена GPT и может содержать ошибки.</small></h6>